netapp_ontap.models.cifs_open_file_share API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_open_file_share`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsOpenFileShareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsOpenFileShare object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `mode: str GET`

    The share mode used to open the file. The share mode can be a combination of: - r: read mode - w: write mode - d: delete - rw: read and write modes - rwd: read, write, and delete modes

    Valid choices:

    - r
    - w
    - d
    - rw
    - rwd
  `name: str GET`

    CIFS share name where the file resides.

    Example: share1